# thanks Martijn Pieters @ stackoverflow.com
# https://stackoverflow.com/a/14692747
# CC-BY-SA-4.0

from functools import reduce
import operator

def get_by_path(root, items):
	"""Access a nested object in root by item sequence."""
	if not items:
		return root
	return reduce(operator.getitem, items, root)

def set_by_path(root, items, value):
	"""Set a value in a nested object in root by item sequence."""
	get_by_path(root, items[:-1])[items[-1]] = value

def del_by_path(root, items):
	"""Delete a key-value in a nested object in root by item sequence."""
	del get_by_path(root, items[:-1])[items[-1]]

def depth(o: dict) -> int:
	"""
	Returns the depth of a dict

	>>> depth({1: {3: {4: 5}}, 2: 3})
	3
	"""
	d = 0
	if isinstance(o, dict):
		d += 1 + (max(depth(v) for v in o.values()) if o else 0)
	return d